@@ -22,7 +22,11 @@ def download_file(model: Text, folder: Text):
             os.environ.get("AWS_S3_BUCKET_RASA_MODELS"),
             folder + "/" + model,
             model,
-            Callback=ProgressPercentage(model),
+            Callback=ProgressPercentage(
+                folder + "/" + model,
+                s3_client,
+                os.environ.get("AWS_S3_BUCKET_RASA_MODELS"),
+            ),
         )
     except ClientError as e:
         logging.error(e)
