@@ -4,9 +4,14 @@ import threading
 
 
 class ProgressPercentage(object):
-    def __init__(self, filename):
+    def __init__(self, filename, client=None, bucket=None):
         self._filename = filename
-        self._size = float(os.path.getsize(filename))
+        if client is None and bucket is None:
+            self._size = float(os.path.getsize(filename))
+        else:
+            self._size = client.head_object(Bucket=bucket, Key=filename).get(
+                "ContentLength"
+            )
         self._seen_so_far = 0
         self._lock = threading.Lock()
 
