@@ -19,10 +19,11 @@ def upload_file(model: Text, folder: Text):
     # Upload the file
     s3_client = boto3.client("s3")
     try:
+        modelName = os.path.basename(model)
         response = s3_client.upload_file(
             model,
             os.environ.get("AWS_S3_BUCKET_RASA_MODELS"),
-            folder + "/" + model,
+            folder + "/" + modelName,
             Callback=ProgressPercentage(model),
         )
     except ClientError as e:
